@@ -1,30 +1,15 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2010  ProFUSION embedded systems
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
- *  Copyright (C) 2010 ProFUSION embedded systems.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#define _GNU_SOURCE
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,12 +22,12 @@
 #include <ofono/modem.h>
 #include <ofono/location-reporting.h>
 
+#include <drivers/atmodem/atutil.h>
+
 #include "gatchat.h"
 #include "gatresult.h"
 #include "gattty.h"
 
-#include "mbmmodem.h"
-
 static const char *none_prefix[] = { NULL };
 static const char *e2gpsctl_prefix[] = { "*E2GPSCTL:", NULL };
 
@@ -98,6 +83,7 @@ static int enable_data_stream(struct ofono_location_reporting *lr)
 {
 	struct ofono_modem *modem;
 	const char *gps_dev;
+	GHashTable *options;
 	GIOChannel *channel;
 	GIOStatus status;
 	gsize written;
@@ -106,7 +92,16 @@ static int enable_data_stream(struct ofono_location_reporting *lr)
 	modem = ofono_location_reporting_get_modem(lr);
 	gps_dev = ofono_modem_get_string(modem, "GPSDevice");
 
-	channel = g_at_tty_open(gps_dev, NULL);
+	options = g_hash_table_new(g_str_hash, g_str_equal);
+	if (options == NULL)
+		return -1;
+
+	g_hash_table_insert(options, "Baud", "115200");
+
+	channel = g_at_tty_open(gps_dev, options);
+
+	g_hash_table_destroy(options);
+
 	if (channel == NULL)
 		return -1;
 
@@ -221,8 +216,7 @@ static void mbm_location_reporting_remove(struct ofono_location_reporting *lr)
 	g_free(gd);
 }
 
-static struct ofono_location_reporting_driver driver = {
-	.name			= "mbmmodem",
+static const struct ofono_location_reporting_driver driver = {
 	.type			= OFONO_LOCATION_REPORTING_TYPE_NMEA,
 	.probe			= mbm_location_reporting_probe,
 	.remove			= mbm_location_reporting_remove,
@@ -230,12 +224,4 @@ static struct ofono_location_reporting_driver driver = {
 	.disable		= mbm_location_reporting_disable,
 };
 
-void mbm_location_reporting_init()
-{
-	ofono_location_reporting_driver_register(&driver);
-}
-
-void mbm_location_reporting_exit()
-{
-	ofono_location_reporting_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(location_reporting, mbmmodem, &driver)
