@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2016  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2016  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_NETMON_H
@@ -26,6 +12,8 @@
 extern "C" {
 #endif
 
+#include <stdarg.h>
+
 #include <ofono/types.h>
 
 struct ofono_netmon;
@@ -33,8 +21,11 @@ struct ofono_netmon;
 typedef void (*ofono_netmon_cb_t)(const struct ofono_error *error, void *data);
 
 struct ofono_netmon_driver {
+	unsigned int flags;
 	int (*probe)(struct ofono_netmon *netmon, unsigned int vendor,
 					void *data);
+	int (*probev)(struct ofono_netmon *netmon, unsigned int vendor,
+					va_list args);
 	void (*remove)(struct ofono_netmon *netmon);
 	void (*request_update)(struct ofono_netmon *netmon,
 					ofono_netmon_cb_t cb, void *data);
@@ -94,7 +85,7 @@ void ofono_netmon_serving_cell_notify(struct ofono_netmon *netmon,
 
 struct ofono_netmon *ofono_netmon_create(struct ofono_modem *modem,
 						unsigned int vendor,
-						const char *driver, void *data);
+						const char *driver, ...);
 
 void ofono_netmon_register(struct ofono_netmon *netmon);
 
